==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/pipes/kotlin/inputs/PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.pipes.kotlin.inputs

import com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
 * @property value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
 */
public data class PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs> {
    override fun toJava():
        com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs =
        com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs].
 */
@PulumiTagMarker
public class PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgsBuilder internal
constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
     */
    @JvmName("fquhfekcftihbuon")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
     */
    @JvmName("thsjtrghwxxnbuje")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
     */
    @JvmName("bobbxokhbuqndamk")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
     */
    @JvmName("mfuldejrxtxrxvou")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs =
        PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs(
            name = name,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/pipes/kotlin/inputs/PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.pipes.kotlin.inputs

import com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
 * @property value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
 */
public data class PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs> {
    override fun toJava(): com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs =
        com.pulumi.aws.pipes.inputs.PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs].
 */
@PulumiTagMarker
public class PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
     */
    @JvmName("nrdbvnvyhoovmrdf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
     */
    @JvmName("csivyufnttkhdpnf")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Name of the pipe. If omitted, the provider will assign a random, unique name. Conflicts with `name_prefix`.
     */
    @JvmName("yjaafyartippuqxt")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Value of parameter to start execution of a SageMaker Model Building Pipeline. Maximum length of 1024.
     */
    @JvmName("tnxckykwepwrjpfv")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs =
        PipeTargetParametersBatchJobParametersContainerOverridesEnvironmentArgs(
            name = name,
            `value` = `value`,
        )
}
